@@ -1,6 +1,7 @@
 
 from pyspec.css_logger import log
-from pyspec.client.SpecConnection import SpecConnection
+from pyspec.client import SpecConnection
+#from pyspec.client.SpecConnection import SpecConnection
 import pyspec.client
 
 def test_splot():
@@ -25,7 +26,10 @@ def test_variables():
 def test_commands():
     pass
 
-spec = SpecConnection('fourc')
+import sys
+
+log.start()
+spec = SpecConnection(sys.argv[1])
 
 test_splot()
 
